from a10sdk.common.A10BaseClass import A10BaseClass


class Authenticate(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param snp: {"enum": ["send-only", "validate"], "type": "string", "description": "'send-only': Send but do not check PDUs on receiving; 'validate': Send and check PDUs on receiving; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "authenticate"
        self.DeviceProxy = ""
        self.snp = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DomainPasswordCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param password: {"minLength": 1, "maxLength": 254, "type": "string", "description": "Set the authentication password for a routing domain (Routing domain password)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "domain-password-cfg"
        self.DeviceProxy = ""
        self.password = ""
        self.authenticate = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SuppressList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param suppress: {"enum": ["external", "interlevel"], "type": "string", "description": "'external': If overload-bit set, don't advertise IP prefixes learned from other protocols; 'interlevel': If overload-bit set, don't advertise IP prefixes learned from another ISIS level; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "suppress-list"
        self.DeviceProxy = ""
        self.suppress = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class OnStartup(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param delay: {"description": "Time in seconds to advertise ourself as overloaded after reboot", "format": "number", "maximum": 86400, "minimum": 5, "not": "wait-for-bgp", "type": "number"}
    :param wait_for_bgp: {"default": 0, "not": "delay", "type": "number", "description": "Let BGP decide when to unset the overload bit", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "on-startup"
        self.DeviceProxy = ""
        self.delay = ""
        self.wait_for_bgp = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SetOverloadBitCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param suppress_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"suppress": {"enum": ["external", "interlevel"], "type": "string", "description": "'external': If overload-bit set, don't advertise IP prefixes learned from other protocols; 'interlevel': If overload-bit set, don't advertise IP prefixes learned from another ISIS level; ", "format": "enum"}, "optional": true}}]}
    :param set_overload_bit: {"default": 0, "type": "number", "description": "Signal other touers not to use us in SPF", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "set-overload-bit-cfg"
        self.DeviceProxy = ""
        self.suppress_list = []
        self.set_overload_bit = ""
        self.on_startup = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NetList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param net: {"minLength": 1, "maxLength": 63, "type": "string", "description": "A Network Entity Title for this process (XX.XXXX. ... .XXXX.XX  Network entity title (NET))", "format": "nasp-string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "net-list"
        self.DeviceProxy = ""
        self.net = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class MetricStyleList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param type: {"default": "narrow", "enum": ["narrow", "wide", "transition", "narrow-transition", "wide-transition"], "type": "string", "description": "'narrow': Use old style of TLVs with narrow metric; 'wide': Use new style of TLVs to carry wider metric; 'transition': Send and accept both styles of TLVs during transition; 'narrow-transition': Send old style of TLVs with narrow metric with accepting both styles of TLVs; 'wide-transition': Send new style of TLVs to carry wider metric with accepting both styles of TLVs; ", "format": "enum"}
    :param level: {"default": "level-1-2", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': Level-1 only; 'level-1-2': Level-1-2; 'level-2': Level-2 only; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "metric-style-list"
        self.DeviceProxy = ""
        self.A10WW_type = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class KeyChainList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param key_chain: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication key-chain for level-1 PDUs; 'level-2': Specify authentication key-chain for level-2 PDUs; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "key-chain-list"
        self.DeviceProxy = ""
        self.key_chain = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ModeList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param mode: {"enum": ["md5"], "type": "string", "description": "'md5': Authentication mode; ", "format": "enum"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication mode for level-1 PDUs; 'level-2': Specify authentication mode for level-2 PDUs; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "mode-list"
        self.DeviceProxy = ""
        self.mode = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SendOnlyList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param send_only: {"default": 0, "type": "number", "description": "Authentication send-only", "format": "flag"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication send-only for level-1 PDUs; 'level-2': Specify authentication send-only for level-2 PDUs; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "send-only-list"
        self.DeviceProxy = ""
        self.send_only = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Authentication(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param key_chain_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"key-chain": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Authentication key-chain (Name of key-chain)", "format": "string"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication key-chain for level-1 PDUs; 'level-2': Specify authentication key-chain for level-2 PDUs; ", "format": "enum"}}}]}
    :param mode_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "mode": {"enum": ["md5"], "type": "string", "description": "'md5': Authentication mode; ", "format": "enum"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication mode for level-1 PDUs; 'level-2': Specify authentication mode for level-2 PDUs; ", "format": "enum"}}}]}
    :param send_only_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"send-only": {"default": 0, "type": "number", "description": "Authentication send-only", "format": "flag"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Specify authentication send-only for level-1 PDUs; 'level-2': Specify authentication send-only for level-2 PDUs; ", "format": "enum"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "authentication"
        self.DeviceProxy = ""
        self.key_chain_list = []
        self.mode_list = []
        self.send_only_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LogAdjacencyChangesCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param state: {"enum": ["detail", "disable"], "type": "string", "description": "'detail': Log changes in adjacency state; 'disable': Disable logging; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "log-adjacency-changes-cfg"
        self.DeviceProxy = ""
        self.state = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SpfIntervalExpList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param max: {"description": "Maximum Delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 50000, "maximum": 2147483647, "minimum": 0, "type": "number"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Set interval for level 1 only; 'level-2': Set interval for level 2 only; ", "format": "enum"}
    :param min: {"description": "Minimum Delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 500, "maximum": 2147483647, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "spf-interval-exp-list"
        self.DeviceProxy = ""
        self.A10WW_max = ""
        self.level = ""
        self.A10WW_min = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PassiveInterfaceList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param lif: {"type": "number", "description": "Logical interface (Lif interface number)", "format": "interface"}
    :param ve: {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}
    :param loopback: {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}
    :param trunk: {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}
    :param ethernet: {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "passive-interface-list"
        self.DeviceProxy = ""
        self.lif = ""
        self.ve = ""
        self.loopback = ""
        self.trunk = ""
        self.ethernet = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SummaryAddressList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param prefix: {"type": "string", "description": "IP network prefix", "format": "ipv4-cidr"}
    :param level: {"default": "level-2", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': Summarize into level-1 area; 'level-1-2': Summarize into both area and sub-domain; 'level-2': Summarize into level-2 sub-domain; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "summary-address-list"
        self.DeviceProxy = ""
        self.prefix = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Authenticate(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param snp: {"enum": ["send-only", "validate"], "type": "string", "description": "'send-only': Send but do not check PDUs on receiving; 'validate': Send and check PDUs on receiving; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "authenticate"
        self.DeviceProxy = ""
        self.snp = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AreaPasswordCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param password: {"minLength": 1, "maxLength": 254, "type": "string", "description": "Configure the authentication password for an area (Area password)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "area-password-cfg"
        self.DeviceProxy = ""
        self.password = ""
        self.authenticate = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LspGenIntervalList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param interval: {"description": "Minimum interval in seconds", "format": "number", "default": 30, "maximum": 120, "minimum": 1, "type": "number"}
    :param level: {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Set interval for level 1 only; 'level-2': Set interval for level 2 only; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "lsp-gen-interval-list"
        self.DeviceProxy = ""
        self.interval = ""
        self.level = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DistanceList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param distance: {"description": "ISIS Administrative Distance (Distance value)", "format": "number", "default": 115, "maximum": 255, "minimum": 1, "type": "number"}
    :param System_ID: {"minLength": 1, "maxLength": 128, "type": "string", "description": "System-ID in XXXX.XXXX.XXXX", "format": "string"}
    :param acl: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access list name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "distance-list"
        self.DeviceProxy = ""
        self.distance = ""
        self.System_ID = ""
        self.acl = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Isis(A10BaseClass):
    
    """Class Description::
    Intermediate System - Intermediate System (IS-IS).

    Class isis supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param max_lsp_lifetime: {"description": "Set maximum LSP lifetime (Maximum LSP lifetime in seconds)", "format": "number", "default": 1200, "optional": true, "maximum": 65535, "minimum": 350, "type": "number"}
    :param tag: {"description": "ISO routing area tag", "format": "string", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}
    :param lsp_refresh_interval: {"description": "Set LSP refresh interval (LSP refresh time in seconds)", "format": "number", "default": 900, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param net_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"net": {"minLength": 1, "maxLength": 63, "type": "string", "description": "A Network Entity Title for this process (XX.XXXX. ... .XXXX.XX  Network entity title (NET))", "format": "nasp-string"}, "optional": true}}]}
    :param bfd: {"optional": true, "enum": ["all-interfaces"], "type": "string", "description": "'all-interfaces': Enable BFD on all interfaces; ", "format": "enum"}
    :param metric_style_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "type": {"default": "narrow", "enum": ["narrow", "wide", "transition", "narrow-transition", "wide-transition"], "type": "string", "description": "'narrow': Use old style of TLVs with narrow metric; 'wide': Use new style of TLVs to carry wider metric; 'transition': Send and accept both styles of TLVs during transition; 'narrow-transition': Send old style of TLVs with narrow metric with accepting both styles of TLVs; 'wide-transition': Send new style of TLVs to carry wider metric with accepting both styles of TLVs; ", "format": "enum"}, "level": {"default": "level-1-2", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': Level-1 only; 'level-1-2': Level-1-2; 'level-2': Level-2 only; ", "format": "enum"}}}]}
    :param ignore_lsp_errors: {"default": 0, "optional": true, "type": "number", "description": "Ignore LSPs with bad checksums", "format": "flag"}
    :param spf_interval_exp_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"max": {"description": "Maximum Delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 50000, "maximum": 2147483647, "minimum": 0, "type": "number"}, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Set interval for level 1 only; 'level-2': Set interval for level 2 only; ", "format": "enum"}, "optional": true, "min": {"description": "Minimum Delay between receiving a change to SPF calculation in milliseconds", "format": "number", "default": 500, "maximum": 2147483647, "minimum": 0, "type": "number"}}}]}
    :param passive_interface_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"lif": {"type": "number", "description": "Logical interface (Lif interface number)", "format": "interface"}, "ve": {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}, "loopback": {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}, "ethernet": {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}, "optional": true}}]}
    :param summary_address_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"prefix": {"type": "string", "description": "IP network prefix", "format": "ipv4-cidr"}, "optional": true, "level": {"default": "level-2", "enum": ["level-1", "level-1-2", "level-2"], "type": "string", "description": "'level-1': Summarize into level-1 area; 'level-1-2': Summarize into both area and sub-domain; 'level-2': Summarize into level-2 sub-domain; ", "format": "enum"}}}]}
    :param adjacency_check: {"default": 1, "optional": true, "type": "number", "description": "Check ISIS neighbor protocol support", "format": "flag"}
    :param default_information: {"optional": true, "enum": ["originate"], "type": "string", "description": "'originate': Distribute a default route; ", "format": "enum"}
    :param lsp_gen_interval_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"interval": {"description": "Minimum interval in seconds", "format": "number", "default": 30, "maximum": 120, "minimum": 1, "type": "number"}, "optional": true, "level": {"enum": ["level-1", "level-2"], "type": "string", "description": "'level-1': Set interval for level 1 only; 'level-2': Set interval for level 2 only; ", "format": "enum"}}}]}
    :param is_type: {"description": "'level-1': Act as a station router only; 'level-1-2': Act as both a station router and an area router; 'level-2-only': Act as an area router only; ", "format": "enum", "default": "level-1", "type": "string", "enum": ["level-1", "level-1-2", "level-2-only"], "optional": true}
    :param protocol_topology: {"default": 0, "optional": true, "type": "number", "description": "Protocol Topology", "format": "flag"}
    :param distance_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distance": {"description": "ISIS Administrative Distance (Distance value)", "format": "number", "default": 115, "maximum": 255, "minimum": 1, "type": "number"}, "System-ID": {"minLength": 1, "maxLength": 128, "type": "string", "description": "System-ID in XXXX.XXXX.XXXX", "format": "string"}, "optional": true, "acl": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access list name", "format": "string"}}}]}
    :param ha_standby_extra_cost: {"description": "Extra IS-IS metric when there is any standby ha group (The extra cost value)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/isis/{tag}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "tag"]

        self.b_key = "isis"
        self.a10_url="/axapi/v3/router/isis/{tag}"
        self.DeviceProxy = ""
        self.domain_password_cfg = {}
        self.max_lsp_lifetime = ""
        self.tag = ""
        self.lsp_refresh_interval = ""
        self.set_overload_bit_cfg = {}
        self.net_list = []
        self.bfd = ""
        self.metric_style_list = []
        self.authentication = {}
        self.ignore_lsp_errors = ""
        self.log_adjacency_changes_cfg = {}
        self.spf_interval_exp_list = []
        self.passive_interface_list = []
        self.summary_address_list = []
        self.adjacency_check = ""
        self.default_information = ""
        self.address_family = {}
        self.redistribute = {}
        self.area_password_cfg = {}
        self.lsp_gen_interval_list = []
        self.is_type = ""
        self.protocol_topology = ""
        self.distance_list = []
        self.ha_standby_extra_cost = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SlbDataCacheTimeout(A10BaseClass):
    
    """Class Description::
    Configure the SLB data cache time-out in seconds.

    Class slb-data-cache-timeout supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param slblimit: {"description": "Cache time-out in seconds, default as 60 seconds", "format": "number", "type": "number", "maximum": 120, "minimum": 5, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/slb-data-cache-timeout`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "slb-data-cache-timeout"
        self.a10_url="/axapi/v3/snmp-server/slb-data-cache-timeout"
        self.DeviceProxy = ""
        self.slblimit = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Authentication(A10BaseClass):
    
    """Class Description::
    Configure AAM authentication settings.

    Class authentication supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param portal_list: {"minItems": 1, "items": {"type": "portal"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"logon-fail": {"type": "object", "properties": {"fail-msg-cfg": {"type": "object", "properties": {"fail-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "fail-face", "type": "string"}, "fail-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "fail-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "fail-msg": {"default": 0, "type": "number", "description": "Configure logon failure message in default logon fail page", "format": "flag"}, "fail-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify logon failure message (Default: Login Failed!!)", "format": "string-rlx"}, "fail-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "fail-color-name", "type": "string"}, "fail-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "fail-color-name": {"not": "fail-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "fail-face": {"not": "fail-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}}}, "welcome-msg-cfg": {"type": "object", "properties": {"wel-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "wel-color-name", "type": "string"}, "wel-color-name": {"not": "wel-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "wel-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "wel-face", "type": "string"}, "wel-face": {"not": "wel-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "wel-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "wel-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "wel-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "wel-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify welcome message (Deault: Try too many times.)", "format": "string-rlx"}, "welcome-msg": {"default": 0, "type": "number", "description": "Configure welcome message in default logon fail page", "format": "flag"}}}, "title-cfg": {"type": "object", "properties": {"title": {"default": 0, "type": "number", "description": "Configure title in default logon fail page", "format": "flag"}, "title-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "title-color-name": {"not": "title-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "title-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "title-face", "type": "string"}, "title-face": {"not": "title-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "title-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "title-color-name", "type": "string"}, "title-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "title-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify title", "format": "string-rlx"}, "title-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}}}, "background": {"type": "object", "properties": {"bgfile": {"description": "Specify background image filename", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "bgcolor", "type": "string"}, "bgstyle": {"enum": ["tile", "stretch", "fit"], "type": "string", "description": "'tile': Tile; 'stretch': Stretch; 'fit': Fit; ", "format": "enum"}, "bgcolor-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "bgcolor-name", "type": "string"}, "bgcolor-name": {"not": "bgcolor-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "bgcolor": {"default": 0, "not": "bgfile", "type": "number", "description": "Specify background color", "format": "flag"}}}, "note-cfg": {"type": "object", "properties": {"note-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify notes", "format": "string-rlx"}, "note-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "note-color-name", "type": "string"}, "note-face": {"not": "note-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "note-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "note-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "note-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "note": {"default": 0, "type": "number", "description": "Configure notes in default logon page", "format": "flag"}, "note-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "note-face", "type": "string"}, "note-color-name": {"not": "note-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}}}}}, "logon": {"type": "object", "properties": {"action-url": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify form action URL in default logon page (Default: /logon.fo)", "format": "string-rlx"}, "password-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify password variable name in default logon page (Default: pwd)", "format": "string-rlx"}, "username-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username variable name in default logon page (Default: user)", "format": "string-rlx"}, "submit-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify submit button text in default logon page (Default: Log In)", "format": "string-rlx"}, "background": {"type": "object", "properties": {"bgfile": {"description": "Specify background image filename", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "bgcolor", "type": "string"}, "bgstyle": {"enum": ["tile", "stretch", "fit"], "type": "string", "description": "'tile': Tile; 'stretch': Stretch; 'fit': Fit; ", "format": "enum"}, "bgcolor-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "bgcolor-name", "type": "string"}, "bgcolor-name": {"not": "bgcolor-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "bgcolor": {"default": 0, "not": "bgfile", "type": "number", "description": "Specify background color", "format": "flag"}}}, "fail-msg-cfg": {"type": "object", "properties": {"fail-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "fail-face", "type": "string"}, "fail-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "fail-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "fail-msg": {"default": 0, "type": "number", "description": "Configure login failure message in default logon page", "format": "flag"}, "fail-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify login failure message (Default: Invalid username or password. Please try again.)", "format": "string-rlx"}, "fail-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "fail-color-name", "type": "string"}, "fail-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "fail-color-name": {"not": "fail-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "fail-face": {"not": "fail-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}}}, "password-cfg": {"type": "object", "properties": {"pass-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "pass-color-name", "type": "string"}, "pass-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "pass-color-name": {"not": "pass-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "pass-face": {"not": "pass-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "pass-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "pass-face", "type": "string"}, "pass-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "pass-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify password text (Default: Password)", "format": "string-rlx"}, "pass-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "password": {"default": 0, "type": "number", "description": "Configure password text in default logon page", "format": "flag"}}}, "username-cfg": {"type": "object", "properties": {"username": {"default": 0, "type": "number", "description": "Configure username text in default logon page", "format": "flag"}, "user-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "user-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username text (Default: User Name)", "format": "string-rlx"}, "user-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "user-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "user-color-name", "type": "string"}, "user-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "user-face", "type": "string"}, "user-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "user-face": {"not": "user-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "user-color-name": {"not": "user-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}}}}}, "logo-cfg": {"type": "object", "properties": {"logo": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify logo image filename", "format": "string-rlx"}, "height": {"description": "Specify logo image height", "minimum": 50, "type": "number", "maximum": 400, "format": "number"}, "width": {"description": "Specify logo image width", "minimum": 50, "type": "number", "maximum": 400, "format": "number"}}}, "name": {"optional": false, "enum": ["default-portal"], "type": "string", "description": "'default-portal': Default portal configuration; ", "format": "enum"}, "change-password": {"type": "object", "properties": {"action-url": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify form action URL in default change password page (Default: /change.fo)", "format": "string-rlx"}, "new-password-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify new password variable name in default change password page (Default: cp_new_pwd)", "format": "string-rlx"}, "new-pwd-cfg": {"type": "object", "properties": {"new-password": {"default": 0, "type": "number", "description": "Configure new password text in default change password page", "format": "flag"}, "new-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "new-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "new-color-name": {"not": "new-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "new-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "new-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "new-color-name", "type": "string"}, "new-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify new password text (Default: New Password)", "format": "string-rlx"}, "new-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "new-face", "type": "string"}, "new-face": {"not": "new-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}}}, "submit-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify submit button text in default change password page (Default: Submit)", "format": "string"}, "welcome-msg-cfg": {"type": "object", "properties": {"wel-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "wel-color-name", "type": "string"}, "wel-color-name": {"not": "wel-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "wel-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "wel-face", "type": "string"}, "wel-face": {"not": "wel-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "wel-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "wel-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "wel-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "wel-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify welcome message (Default: Please change your password.)", "format": "string-rlx"}, "welcome-msg": {"default": 0, "type": "number", "description": "Configure welcome message in default change password page", "format": "flag"}}}, "confirm-password-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify confirm password variable name in default change password page (Default: cp_cfm_pwd)", "format": "string-rlx"}, "title-cfg": {"type": "object", "properties": {"title": {"default": 0, "type": "number", "description": "Configure title in default change password page", "format": "flag"}, "title-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "title-color-name": {"not": "title-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "title-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "title-face", "type": "string"}, "title-face": {"not": "title-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "title-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "title-color-name", "type": "string"}, "title-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "title-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify title", "format": "string-rlx"}, "title-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}}}, "reset-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify reset button text in default change password page (Default: Reset)", "format": "string"}, "username-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username variable name in default change password page (Default: cp_usr)", "format": "string-rlx"}, "old-pwd-cfg": {"type": "object", "properties": {"old-face": {"not": "old-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "old-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "old-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "old-color-name", "type": "string"}, "old-password": {"default": 0, "type": "number", "description": "Configure old password text in default change password page", "format": "flag"}, "old-color-name": {"not": "old-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "old-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "old-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify old password text (Default: Old Password)", "format": "string-rlx"}, "old-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "old-face", "type": "string"}, "old-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}}}, "background": {"type": "object", "properties": {"bgfile": {"description": "Specify background image filename", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "bgcolor", "type": "string"}, "bgstyle": {"enum": ["tile", "stretch", "fit"], "type": "string", "description": "'tile': Tile; 'stretch': Stretch; 'fit': Fit; ", "format": "enum"}, "bgcolor-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "bgcolor-name", "type": "string"}, "bgcolor-name": {"not": "bgcolor-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "bgcolor": {"default": 0, "not": "bgfile", "type": "number", "description": "Specify background color", "format": "flag"}}}, "old-password-var": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify old password variable name in default change password page (Default: cp_old_pwd)", "format": "string-rlx"}, "cfm-pwd-cfg": {"type": "object", "properties": {"cfm-color-name": {"not": "cfm-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}, "cfm-face": {"not": "cfm-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "cfm-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "cfm-color-name", "type": "string"}, "cfm-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "cfm-face", "type": "string"}, "cfm-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "cfm-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "cfm-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify confirm password text (Default: Confirm New Password)", "format": "string-rlx"}, "confirm-password": {"default": 0, "type": "number", "description": "Configure confirm password text in default change password page", "format": "flag"}, "cfm-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}}}, "username-cfg": {"type": "object", "properties": {"username": {"default": 0, "type": "number", "description": "Configure username text in default change password page", "format": "flag"}, "user-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "user-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username text (Default: Username)", "format": "string-rlx"}, "user-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "user-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "user-color-name", "type": "string"}, "user-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "user-face", "type": "string"}, "user-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "user-face": {"not": "user-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "user-color-name": {"not": "user-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}}}, "note-cfg": {"type": "object", "properties": {"note-text": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify notes", "format": "string-rlx"}, "note-color-value": {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "note-color-name", "type": "string"}, "note-face": {"not": "note-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}, "note-font": {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}, "note-color": {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}, "note-size": {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "note": {"default": 0, "type": "number", "description": "Configure notes in default change password page", "format": "flag"}, "note-font-custom": {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "note-face", "type": "string"}, "note-color-name": {"not": "note-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}}}}}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/portal/{name}"}
    :param service_group_list: {"minItems": 1, "items": {"type": "service-group"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"health-check-disable": {"description": "Disable health check", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}, "protocol": {"description": "'tcp': TCP AAM service; 'udp': UDP AAM service; ", "format": "enum", "type": "string", "enum": ["tcp", "udp"], "modify-not-allowed": 1, "optional": true}, "name": {"description": "Specify AAM service group name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "lb-method": {"optional": true, "enum": ["round-robin"], "type": "string", "description": "'round-robin': Round robin on server level; ", "format": "enum"}, "member-list": {"minItems": 1, "items": {"type": "member"}, "uniqueItems": true, "array": [{"required": ["name", "port"], "properties": {"member-priority": {"description": "Priority of Port in the Group", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": true}, "name": {"description": "Member name", "format": "comp-string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/server/ldap"}, "member-state": {"description": "'enable': Enable member service port; 'disable': Disable member service port; ", "format": "enum", "default": "enable", "type": "string", "enum": ["enable", "disable"], "optional": true}, "port": {"description": "Port number", "format": "number", "default": 65534, "optional": false, "maximum": 65534, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/service-group/{name}/member/{name}+{port}"}, "health-check": {"description": "Health Check (Monitor Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "health-check-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/service-group/{name}"}
    :param template_list: {"minItems": 1, "items": {"type": "template"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"logout-idle-timeout": {"description": "Specify idle logout time (Specify idle timeout in seconds, default is 300)", "format": "number", "default": 300, "optional": true, "maximum": 86400, "minimum": 1, "type": "number"}, "cookie-domain": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cookie-dmn": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify domain scope for the authentication (ex: .a10networks.com)", "format": "string-rlx"}, "optional": true}}]}, "name": {"description": "Authentication template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "relay": {"description": "Specify authentication relay (Specify authentication relay template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/relay/http-basic/instance"}, "logon": {"description": "Specify authentication logon (Specify authentication logon template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/logon/form-based"}, "saml-sp": {"description": "Specify SAML service provider", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "logout-url": {"description": "Specify logout url (Specify logout url string)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}, "service-group": {"description": "Bind an authentication service group to this template (Specify authentication service group name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "not": "server", "type": "string", "$ref": "/axapi/v3/aam/authentication/service-group"}, "server": {"description": "Specify authentication server (Specify authentication server template name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "not": "service-group", "type": "string", "$ref": "/axapi/v3/aam/authentication/server/ldap/instance"}, "cookie-domain-group": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cookie-dmngrp": {"description": "Specify group id to join in the cookie-domain", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}, "optional": true}}]}, "log": {"description": "'use-partition-level-config': Use configuration of authentication-log enable command; 'enable': Enable authentication logs for this template; 'disable': Disable authentication logs for this template; ", "format": "enum", "default": "use-partition-level-config", "type": "string", "enum": ["use-partition-level-config", "enable", "disable"], "optional": true}, "account": {"description": "Specify AD domain account", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/account/kerberos-spn"}, "saml-idp": {"description": "Specify SAML identity provider", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "type": {"optional": true, "enum": ["saml", "standard"], "type": "string", "description": "'saml': SAML authentication template; 'standard': Standard authentication template; ", "format": "enum"}, "cookie-max-age": {"description": "Configure Max-Age for authentication session cookie (Configure Max-Age in seconds. Default is 604800 (1 week).)", "format": "number", "default": 604800, "optional": true, "maximum": 2592000, "minimum": 1, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/template/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "authentication"
        self.a10_url="/axapi/v3/aam/authentication"
        self.DeviceProxy = ""
        self.account = {}
        self.portal_list = []
        self.log = {}
        self.relay = {}
        self.saml = {}
        self.service_group_list = []
        self.server = {}
        self.template_list = []
        self.logon = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class XmlSchema(A10BaseClass):
    
    """Class Description::
    Manage XML-Schema files.

    Class xml-schema supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param max_filesize: {"description": "Set maximum XML-Schema file size (Maximum file size in KBytes, default is 32K)", "partition-visibility": "shared", "default": 32, "optional": true, "format": "number", "maximum": 256, "minimum": 16, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/waf/xml-schema`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "xml-schema"
        self.a10_url="/axapi/v3/waf/xml-schema"
        self.DeviceProxy = ""
        self.max_filesize = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AsPath(A10BaseClass):
    
    """Class Description::
    Configure an AS-path list for BGP.

    Class as-path supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param access_list: {"description": "Specify an access list name (Regular expression access-list name)", "format": "string", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}
    :param action: {"optional": false, "enum": ["deny", "permit"], "type": "string", "description": "'deny': Specify packets to reject; 'permit': Specify packets to forward; ", "format": "enum"}
    :param value: {"optional": false, "type": "string", "description": "A regular-expression to match the BGP AS paths", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/as-path/{access_list}+{action}+{value}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "access_list","action","value"]

        self.b_key = "as-path"
        self.a10_url="/axapi/v3/ip/as-path/{access_list}+{action}+{value}"
        self.DeviceProxy = ""
        self.access_list = ""
        self.action = ""
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Pcp(A10BaseClass):
    
    """Class Description::
    Set Port Control Protocol parameters.

    Class pcp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param default_template: {"description": "Bind the default template for PCP (Bind a PCP template)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/pcp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "pcp"
        self.a10_url="/axapi/v3/cgnv6/pcp"
        self.DeviceProxy = ""
        self.default_template = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ssl_sid_session_ok: {"description": "Create SSL SID ok", "format": "counter", "type": "number", "oid": "47", "optional": true, "size": "8"}
    :param sssl_sid_not_match: {"description": "Server SSL SID not match", "format": "counter", "type": "number", "oid": "44", "optional": true, "size": "8"}
    :param cookie_invalid: {"description": "Invalid persist cookie", "format": "counter", "type": "number", "oid": "53", "optional": true, "size": "8"}
    :param cookie_persist_fail: {"description": "Cookie persist fail", "format": "counter", "type": "number", "oid": "50", "optional": true, "size": "8"}
    :param url_hash_sec: {"description": "URL hash persist (sec)", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param header_hash_pri: {"description": "Header hash persist(pri)", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param src_ip_hash_pri: {"description": "SRC IP hash persist(pri)", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param src_ip_new_sess_cache: {"description": "SRC IP new sess (cache)", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param src_ip_new_sess_sel_fail: {"description": "SRC IP new sess fail (s)", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param sssl_sid_match: {"description": "Server SSL SID match", "format": "counter", "type": "number", "oid": "43", "optional": true, "size": "8"}
    :param dst_ip_hash_sec: {"description": "DST IP hash persist(sec)", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "8"}
    :param src_ip_hash_sec: {"description": "SRC IP hash persist(sec)", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param cookie_not_found: {"description": "Persist cookie not found", "format": "counter", "type": "number", "oid": "51", "optional": true, "size": "8"}
    :param dst_ip_new_sess_cache: {"description": "DST IP new sess (cache)", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param cssl_sid_match: {"description": "Client SSL SID match", "format": "counter", "type": "number", "oid": "39", "optional": true, "size": "8"}
    :param hash_tbl_create_fail: {"description": "Hash tbl create fail", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param dst_ip_new_sess_sel: {"description": "DST IP new sess (select)", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "8"}
    :param src_ip: {"description": "SRC IP persist ok", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param ssl_sid_persist_fail: {"description": "SSL SID persist fail", "format": "counter", "type": "number", "oid": "46", "optional": true, "size": "8"}
    :param dst_ip_hash_fail: {"description": "DST IP hash persist fail", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "8"}
    :param hash_tbl_rst_adddel: {"description": "Hash tbl reset (add/del)", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param cssl_sid_not_match: {"description": "Client SSL SID not match", "format": "counter", "type": "number", "oid": "40", "optional": true, "size": "8"}
    :param ssl_sid_session_fail: {"description": "Create SSL SID fail", "format": "counter", "type": "number", "oid": "48", "optional": true, "size": "8"}
    :param dst_ip_hash_pri: {"description": "DST IP hash persist(pri)", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "8"}
    :param url_hash_enqueue: {"description": "URL hash persist (enQ)", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param hash_tbl_create_ok: {"description": "Hash tbl create ok", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param cookie_pass_thru: {"description": "Persist cookie Pass-thru", "format": "counter", "type": "number", "oid": "52", "optional": true, "size": "8"}
    :param sssl_sid_reset: {"description": "Server SSL SID reset", "format": "counter", "type": "number", "oid": "42", "optional": true, "size": "8"}
    :param src_ip_new_sess_cache_fail: {"description": "SRC IP new sess fail (c)", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param dst_ip_new_sess_sel_fail: {"description": "DST IP new sess fail (s)", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "8"}
    :param url_hash_pri: {"description": "URL hash persist (pri)", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param url_hash_fail: {"description": "URL hash persist fail", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param hash_tbl_free: {"description": "Hash tbl free", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param src_ip_enforce: {"description": "Enforce higher priority", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param hash_tbl_rst_updown: {"description": "Hash tbl reset (up/down)", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param hash_tbl_trylock_fail: {"description": "Hash tbl lock fail", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param cssl_sid_not_found: {"description": "Client SSL SID not found", "format": "counter", "type": "number", "oid": "38", "optional": true, "size": "8"}
    :param dst_ip_hash_enqueue: {"description": "DST IP hash persist(enQ)", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "8"}
    :param header_hash_sec: {"description": "Header hash persist(sec)", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param sssl_sid_not_found: {"description": "Server SSL SID not found", "format": "counter", "type": "number", "oid": "41", "optional": true, "size": "8"}
    :param src_ip_new_sess_sel: {"description": "SRC IP new sess (select)", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param header_hash_fail: {"description": "Header hash persist fail", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param dst_ip_fail: {"description": "DST IP persist fail", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param src_ip_hash_enqueue: {"description": "SRC IP hash persist(enQ)", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param header_hash_enqueue: {"description": "Header hash persist(enQ)", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param src_ip_enqueue: {"description": "SRC IP persist enqueue", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param src_ip_hash_fail: {"description": "SRC IP hash persist fail", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param cookie_persist_ok: {"description": "Cookie persist ok", "format": "counter", "type": "number", "oid": "49", "optional": true, "size": "8"}
    :param dst_ip_enqueue: {"description": "DST IP persist enqueue", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param dst_ip_new_sess_cache_fail: {"description": "DST IP new sess fail (c)", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "8"}
    :param dst_ip: {"description": "DST IP persist ok", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param src_ip_fail: {"description": "SRC IP persist fail", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param ssl_sid_persist_ok: {"description": "SSL SID persist ok", "format": "counter", "type": "number", "oid": "45", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.ssl_sid_session_ok = ""
        self.sssl_sid_not_match = ""
        self.cookie_invalid = ""
        self.cookie_persist_fail = ""
        self.url_hash_sec = ""
        self.header_hash_pri = ""
        self.src_ip_hash_pri = ""
        self.src_ip_new_sess_cache = ""
        self.src_ip_new_sess_sel_fail = ""
        self.sssl_sid_match = ""
        self.dst_ip_hash_sec = ""
        self.src_ip_hash_sec = ""
        self.cookie_not_found = ""
        self.dst_ip_new_sess_cache = ""
        self.cssl_sid_match = ""
        self.hash_tbl_create_fail = ""
        self.dst_ip_new_sess_sel = ""
        self.src_ip = ""
        self.ssl_sid_persist_fail = ""
        self.dst_ip_hash_fail = ""
        self.hash_tbl_rst_adddel = ""
        self.cssl_sid_not_match = ""
        self.ssl_sid_session_fail = ""
        self.dst_ip_hash_pri = ""
        self.url_hash_enqueue = ""
        self.hash_tbl_create_ok = ""
        self.cookie_pass_thru = ""
        self.sssl_sid_reset = ""
        self.src_ip_new_sess_cache_fail = ""
        self.dst_ip_new_sess_sel_fail = ""
        self.url_hash_pri = ""
        self.url_hash_fail = ""
        self.hash_tbl_free = ""
        self.src_ip_enforce = ""
        self.hash_tbl_rst_updown = ""
        self.hash_tbl_trylock_fail = ""
        self.cssl_sid_not_found = ""
        self.dst_ip_hash_enqueue = ""
        self.header_hash_sec = ""
        self.sssl_sid_not_found = ""
        self.src_ip_new_sess_sel = ""
        self.header_hash_fail = ""
        self.dst_ip_fail = ""
        self.src_ip_hash_enqueue = ""
        self.header_hash_enqueue = ""
        self.src_ip_enqueue = ""
        self.src_ip_hash_fail = ""
        self.cookie_persist_ok = ""
        self.dst_ip_enqueue = ""
        self.dst_ip_new_sess_cache_fail = ""
        self.dst_ip = ""
        self.src_ip_fail = ""
        self.ssl_sid_persist_ok = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Persist(A10BaseClass):
    
    """Class Description::
    Statistics for the object persist.

    Class persist supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/persist/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "persist"
        self.a10_url="/axapi/v3/slb/persist/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class VportList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param vserver: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param port: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vport-list"
        self.DeviceProxy = ""
        self.vserver = ""
        self.port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Events(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param failures: {"type": "number", "format": "number"}
    :param aborts: {"type": "number", "format": "number"}
    :param total_executions: {"type": "number", "format": "number"}
    :param event_type: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "events"
        self.DeviceProxy = ""
        self.failures = ""
        self.aborts = ""
        self.total_executions = ""
        self.event_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class FileList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param syntax: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param vport_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"vserver": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "port": {"type": "number", "format": "number"}}}]}
    :param file: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param vport: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param events: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"failures": {"type": "number", "format": "number"}, "aborts": {"type": "number", "format": "number"}, "optional": true, "total-executions": {"type": "number", "format": "number"}, "event-type": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "file-list"
        self.DeviceProxy = ""
        self.syntax = ""
        self.vport_list = []
        self.A10WW_file = ""
        self.vport = ""
        self.events = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param file_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"syntax": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "vport-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"vserver": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "port": {"type": "number", "format": "number"}}}]}, "file": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "vport": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "events": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"failures": {"type": "number", "format": "number"}, "aborts": {"type": "number", "format": "number"}, "optional": true, "total-executions": {"type": "number", "format": "number"}, "event-type": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}]}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.file_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Aflex(A10BaseClass):
    
    """Class Description::
    Operational Status for the object aflex.

    Class aflex supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/file/aflex/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "aflex"
        self.a10_url="/axapi/v3/file/aflex/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ipv4Gateway(A10BaseClass):
    
    """Class Description::
    IPv4 Gateway.

    Class ipv4-gateway supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ip_address: {"optional": false, "type": "string", "description": "IP Address", "format": "ipv4-address"}
    :param priority_cost: {"description": "The amount the priority will decrease. help-val Priority", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/vrid/{vrid_val}/tracking-options/gateway/ipv4-gateway/{ip_address}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ip_address"]

        self.b_key = "ipv4-gateway"
        self.a10_url="/axapi/v3/vrrp-a/vrid/{vrid_val}/tracking-options/gateway/ipv4-gateway/{ip_address}"
        self.DeviceProxy = ""
        self.ip_address = ""
        self.priority_cost = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param fullcone_created_previous_epoch_first: {"optional": true, "size": "8", "type": "number", "oid": "5", "format": "counter"}
    :param fullcone_created_previous_epoch_last: {"optional": true, "size": "8", "type": "number", "oid": "8", "format": "counter"}
    :param data_sessions_previous_epoch_first: {"optional": true, "size": "8", "type": "number", "oid": "4", "format": "counter"}
    :param user_quote_created_current_epoch: {"optional": true, "size": "8", "type": "number", "oid": "3", "format": "counter"}
    :param user_quote_created_previous_epoch_first: {"optional": true, "size": "8", "type": "number", "oid": "6", "format": "counter"}
    :param user_quote_created_previous_epoch_last: {"optional": true, "size": "8", "type": "number", "oid": "9", "format": "counter"}
    :param fullcone_created_current_epoch: {"optional": true, "size": "8", "type": "number", "oid": "2", "format": "counter"}
    :param data_sessions_previous_epoch_last: {"optional": true, "size": "8", "type": "number", "oid": "7", "format": "counter"}
    :param data_sessions_current_epoch: {"optional": true, "size": "8", "type": "number", "oid": "1", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.fullcone_created_previous_epoch_first = ""
        self.fullcone_created_previous_epoch_last = ""
        self.data_sessions_previous_epoch_first = ""
        self.user_quote_created_current_epoch = ""
        self.user_quote_created_previous_epoch_first = ""
        self.user_quote_created_previous_epoch_last = ""
        self.fullcone_created_current_epoch = ""
        self.data_sessions_previous_epoch_last = ""
        self.data_sessions_current_epoch = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Performance(A10BaseClass):
    
    """Class Description::
    Statistics for the object performance.

    Class performance supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn/performance/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "performance"
        self.a10_url="/axapi/v3/cgnv6/lsn/performance/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class CipherCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param priority: {"description": "Cipher priority (Cipher priority (default 1))", "format": "number", "default": 1, "maximum": 100, "minimum": 1, "type": "number"}
    :param cipher_suite: {"enum": ["SSL3_RSA_DES_192_CBC3_SHA", "SSL3_RSA_DES_40_CBC_SHA", "SSL3_RSA_DES_64_CBC_SHA", "SSL3_RSA_RC4_128_MD5", "SSL3_RSA_RC4_128_SHA", "SSL3_RSA_RC4_40_MD5", "TLS1_RSA_AES_128_SHA", "TLS1_RSA_AES_256_SHA", "TLS1_RSA_EXPORT1024_RC4_56_MD5", "TLS1_RSA_EXPORT1024_RC4_56_SHA", "TLS1_RSA_AES_128_SHA256", "TLS1_RSA_AES_256_SHA256"], "type": "string", "description": "'SSL3_RSA_DES_192_CBC3_SHA': SSL3_RSA_DES_192_CBC3_SHA; 'SSL3_RSA_DES_40_CBC_SHA': SSL3_RSA_DES_40_CBC_SHA; 'SSL3_RSA_DES_64_CBC_SHA': SSL3_RSA_DES_64_CBC_SHA; 'SSL3_RSA_RC4_128_MD5': SSL3_RSA_RC4_128_MD5; 'SSL3_RSA_RC4_128_SHA': SSL3_RSA_RC4_128_SHA; 'SSL3_RSA_RC4_40_MD5': SSL3_RSA_RC4_40_MD5; 'TLS1_RSA_AES_128_SHA': TLS1_RSA_AES_128_SHA; 'TLS1_RSA_AES_256_SHA': TLS1_RSA_AES_256_SHA; 'TLS1_RSA_EXPORT1024_RC4_56_MD5': TLS1_RSA_EXPORT1024_RC4_56_MD5; 'TLS1_RSA_EXPORT1024_RC4_56_SHA': TLS1_RSA_EXPORT1024_RC4_56_SHA; 'TLS1_RSA_AES_128_SHA256': TLS1_RSA_AES_128_SHA256; 'TLS1_RSA_AES_256_SHA256': TLS1_RSA_AES_256_SHA256; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cipher-cfg"
        self.DeviceProxy = ""
        self.priority = ""
        self.cipher_suite = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Cipher(A10BaseClass):
    
    """Class Description::
    SSL Cipher Template.

    Class cipher supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Cipher Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param cipher_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Cipher priority (Cipher priority (default 1))", "format": "number", "default": 1, "maximum": 100, "minimum": 1, "type": "number"}, "cipher-suite": {"enum": ["SSL3_RSA_DES_192_CBC3_SHA", "SSL3_RSA_DES_40_CBC_SHA", "SSL3_RSA_DES_64_CBC_SHA", "SSL3_RSA_RC4_128_MD5", "SSL3_RSA_RC4_128_SHA", "SSL3_RSA_RC4_40_MD5", "TLS1_RSA_AES_128_SHA", "TLS1_RSA_AES_256_SHA", "TLS1_RSA_EXPORT1024_RC4_56_MD5", "TLS1_RSA_EXPORT1024_RC4_56_SHA", "TLS1_RSA_AES_128_SHA256", "TLS1_RSA_AES_256_SHA256"], "type": "string", "description": "'SSL3_RSA_DES_192_CBC3_SHA': SSL3_RSA_DES_192_CBC3_SHA; 'SSL3_RSA_DES_40_CBC_SHA': SSL3_RSA_DES_40_CBC_SHA; 'SSL3_RSA_DES_64_CBC_SHA': SSL3_RSA_DES_64_CBC_SHA; 'SSL3_RSA_RC4_128_MD5': SSL3_RSA_RC4_128_MD5; 'SSL3_RSA_RC4_128_SHA': SSL3_RSA_RC4_128_SHA; 'SSL3_RSA_RC4_40_MD5': SSL3_RSA_RC4_40_MD5; 'TLS1_RSA_AES_128_SHA': TLS1_RSA_AES_128_SHA; 'TLS1_RSA_AES_256_SHA': TLS1_RSA_AES_256_SHA; 'TLS1_RSA_EXPORT1024_RC4_56_MD5': TLS1_RSA_EXPORT1024_RC4_56_MD5; 'TLS1_RSA_EXPORT1024_RC4_56_SHA': TLS1_RSA_EXPORT1024_RC4_56_SHA; 'TLS1_RSA_AES_128_SHA256': TLS1_RSA_AES_128_SHA256; 'TLS1_RSA_AES_256_SHA256': TLS1_RSA_AES_256_SHA256; ", "format": "enum"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/cipher/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "cipher"
        self.a10_url="/axapi/v3/slb/template/cipher/{name}"
        self.DeviceProxy = ""
        self.name = ""
        self.cipher_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class HostList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dns_host: {"minLength": 1, "maxLength": 31, "type": "string", "description": "DNS remote host", "format": "string"}
    :param ipv4_mask: {"type": "string", "description": "IPV4 mask", "format": "ipv4-netmask"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "host-list"
        self.DeviceProxy = ""
        self.dns_host = ""
        self.ipv4_mask = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv4List(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv4_host: {"type": "string", "description": "IPV4 remote host", "format": "ipv4-address"}
    :param ipv4_mask: {"type": "string", "description": "IPV4 mask", "format": "ipv4-netmask"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv4-list"
        self.DeviceProxy = ""
        self.ipv4_host = ""
        self.ipv4_mask = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6List(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv6_host: {"type": "string", "description": "IPV6 remote host", "format": "ipv6-address"}
    :param ipv6_mask: {"description": "IPV6 mask", "minimum": 1, "type": "number", "maximum": 128, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6-list"
        self.DeviceProxy = ""
        self.ipv6_host = ""
        self.ipv6_mask = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Remote(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param host_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dns-host": {"minLength": 1, "maxLength": 31, "type": "string", "description": "DNS remote host", "format": "string"}, "optional": true, "ipv4-mask": {"type": "string", "description": "IPV4 mask", "format": "ipv4-netmask"}}}]}
    :param ipv4_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "ipv4-host": {"type": "string", "description": "IPV4 remote host", "format": "ipv4-address"}, "ipv4-mask": {"type": "string", "description": "IPV4 mask", "format": "ipv4-netmask"}}}]}
    :param ipv6_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv6-host": {"type": "string", "description": "IPV6 remote host", "format": "ipv6-address"}, "optional": true, "ipv6-mask": {"description": "IPV6 mask", "minimum": 1, "type": "number", "maximum": 128, "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "remote"
        self.DeviceProxy = ""
        self.host_list = []
        self.ipv4_list = []
        self.ipv6_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oid(A10BaseClass):
    
    """Class Description::
    Define a remote entity to which user belongs.

    Class oid supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param oid_val: {"description": "specific the oid (The oid value, object-key)", "format": "string", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/community/read/{user}/oid/{oid_val}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "oid_val"]

        self.b_key = "oid"
        self.a10_url="/axapi/v3/snmp-server/community/read/{user}/oid/{oid_val}"
        self.DeviceProxy = ""
        self.remote = {}
        self.oid_val = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ser_connecting_err: {"description": "Serv CTNG state error", "format": "counter", "type": "number", "oid": "42", "optional": true, "size": "8"}
    :param svrsel_fail: {"description": "Server selection failure", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param curr: {"description": "Current proxy conns", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param unsupported_prot_value: {"description": "Unsupported PROT", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "8"}
    :param cc: {"description": "clear ctrl port packet", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param request: {"description": "Total FTP Request", "format": "counter", "type": "number", "oid": "48", "optional": true, "size": "8"}
    :param server_response_err: {"description": "Serv RESP state error", "format": "counter", "type": "number", "oid": "43", "optional": true, "size": "8"}
    :param unsupported_pbsz_value: {"description": "Unsupported PBSZ", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "8"}
    :param cant_find_pasv: {"description": "cant find pasv", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param pbsz: {"description": "pbsz cmd", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param pasv: {"description": "pasv cmd", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param smp_v4_fail: {"description": "Serv Sel SMPv4 fail", "format": "counter", "type": "number", "oid": "39", "optional": true, "size": "8"}
    :param no_route: {"description": "no route failure", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param total: {"description": "Total proxy conns", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param feat: {"description": "feat packet", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param port: {"description": "port cmd", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param data_total: {"description": "Total Data Proxy", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param auth_tls: {"description": "auth tls cmd", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param request_dont_care: {"description": "other cmd", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param cl_est_err: {"description": "Client EST state erro", "format": "counter", "type": "number", "oid": "41", "optional": true, "size": "8"}
    :param cl_request_err: {"description": "Client RQ state error", "format": "counter", "type": "number", "oid": "44", "optional": true, "size": "8"}
    :param prot: {"description": "prot cmd", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param insert_tuple_fail: {"description": "Serv Sel insert tuple fail", "format": "counter", "type": "number", "oid": "40", "optional": true, "size": "8"}
    :param line_mem_freed: {"description": "request line freed", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param invalid_start_line: {"description": "invalid start line", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param epsv: {"description": "epsv command", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param rsv_persist_conn_fail: {"description": "Serv Sel Persist fail", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "8"}
    :param control_to_ssl: {"description": "Control chn ssl", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "8"}
    :param cant_find_epsv: {"description": "cant find epsv", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param smp_v6_fail: {"description": "Serv Sel SMPv6 fail", "format": "counter", "type": "number", "oid": "38", "optional": true, "size": "8"}
    :param data_curr: {"description": "Current Data Proxy", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param snat_fail: {"description": "source nat failure", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param data_ssl: {"description": "data ssl force", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param data_serv_connecting_err: {"description": "Data Serv CTNG error", "format": "counter", "type": "number", "oid": "46", "optional": true, "size": "8"}
    :param auth_unsupported: {"description": "Unsupported auth", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param pasv_addr_ne_server: {"description": "psv addr not equal to svr", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param smp_create_fail: {"description": "smp create fail", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param control_to_clear: {"description": "Control chn clear txt", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "8"}
    :param line_too_long: {"description": "line too long", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param data_serv_connected_err: {"description": "Data Serv CTED error", "format": "counter", "type": "number", "oid": "47", "optional": true, "size": "8"}
    :param client_auth_tls: {"description": "client auth tls", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param adat: {"description": "adat cmd", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param bad_sequence: {"description": "Bad Sequence", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "8"}
    :param unsupported_command: {"description": "Unsupported cmd", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "8"}
    :param data_send_fail: {"description": "data send fail", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param data_conn_start_err: {"description": "Data Start state error", "format": "counter", "type": "number", "oid": "45", "optional": true, "size": "8"}
    :param data_server_conn_fail: {"description": "data svr conn fail", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.ser_connecting_err = ""
        self.svrsel_fail = ""
        self.curr = ""
        self.unsupported_prot_value = ""
        self.cc = ""
        self.request = ""
        self.server_response_err = ""
        self.unsupported_pbsz_value = ""
        self.cant_find_pasv = ""
        self.pbsz = ""
        self.pasv = ""
        self.smp_v4_fail = ""
        self.no_route = ""
        self.total = ""
        self.feat = ""
        self.port = ""
        self.data_total = ""
        self.auth_tls = ""
        self.request_dont_care = ""
        self.cl_est_err = ""
        self.cl_request_err = ""
        self.prot = ""
        self.insert_tuple_fail = ""
        self.line_mem_freed = ""
        self.invalid_start_line = ""
        self.epsv = ""
        self.rsv_persist_conn_fail = ""
        self.control_to_ssl = ""
        self.cant_find_epsv = ""
        self.smp_v6_fail = ""
        self.data_curr = ""
        self.snat_fail = ""
        self.data_ssl = ""
        self.data_serv_connecting_err = ""
        self.auth_unsupported = ""
        self.pasv_addr_ne_server = ""
        self.smp_create_fail = ""
        self.control_to_clear = ""
        self.line_too_long = ""
        self.data_serv_connected_err = ""
        self.client_auth_tls = ""
        self.adat = ""
        self.bad_sequence = ""
        self.unsupported_command = ""
        self.data_send_fail = ""
        self.data_conn_start_err = ""
        self.data_server_conn_fail = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class FtpProxy(A10BaseClass):
    
    """Class Description::
    Statistics for the object ftp-proxy.

    Class ftp-proxy supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/ftp-proxy/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ftp-proxy"
        self.a10_url="/axapi/v3/slb/ftp-proxy/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Route(A10BaseClass):
    
    """Class Description::
    Establish static routes.

    Class route supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param rib_list: {"minItems": 1, "items": {"type": "rib"}, "uniqueItems": true, "array": [{"required": ["ipv6-address"], "properties": {"ipv6-address": {"optional": false, "type": "string", "description": "IPV6 address", "format": "ipv6-address-plen"}, "ipv6-nexthop-ipv6": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distance": {"description": "Distance value for this route", "format": "number", "default": 1, "maximum": 255, "minimum": 1, "type": "number"}, "ipv6-nexthop": {"type": "string", "description": "Forwarding router's address", "format": "ipv6-address"}, "description": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Description for static route", "format": "string-rlx"}, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}, "ethernet": {"type": "number", "description": "Ethernet interface (Ethernet interface number)", "format": "interface"}, "optional": true, "ve": {"type": "number", "description": "Virtual Ethernet interface (Virtual Ethernet interface number)", "format": "interface"}}}]}}}], "type": "array", "$ref": "/axapi/v3/ipv6/route/rib/{ipv6-address}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ipv6/route`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "route"
        self.a10_url="/axapi/v3/ipv6/route"
        self.DeviceProxy = ""
        self.rib_list = []
        self.static = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param hits: {"description": "Number of times the record has been used", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.hits = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DnsARecordIpv4(A10BaseClass):
    
    """Class Description::
    Statistics for the object dns-a-record-ipv4.

    Class dns-a-record-ipv4 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param dns_a_record_ip: {"optional": false, "oid": "1001", "type": "string", "description": "Specify IP address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/dns-a-record/dns-a-record-ipv4/{dns_a_record_ip}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "dns_a_record_ip"]

        self.b_key = "dns-a-record-ipv4"
        self.a10_url="/axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/dns-a-record/dns-a-record-ipv4/{dns_a_record_ip}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.dns_a_record_ip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class File(A10BaseClass):
    
    """Class Description::
    Logging to file.

    Class file supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param rotate: {"description": "Log file rotation (Number of backup files)", "format": "number", "type": "number", "maximum": 100, "minimum": 0, "optional": true}
    :param name: {"description": "Logging filename (File name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 32, "type": "string"}
    :param per_protocol: {"default": 0, "optional": true, "type": "number", "description": "Per protocol", "format": "flag"}
    :param size: {"description": "Log file maximum size (File size in MBytes)", "format": "number", "type": "number", "maximum": 1000000, "minimum": 0, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/log/file`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "file"
        self.a10_url="/axapi/v3/router/log/file"
        self.DeviceProxy = ""
        self.rotate = ""
        self.name = ""
        self.per_protocol = ""
        self.size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param interface_not_configured: {"description": "LW-4over6 Interfaces not Configured Drops", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param no_match_icmp_sent: {"description": "No-Reverse-Match ICMP Sent", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param self_hairpinning_drop: {"description": "Self-Hairpinning Drops", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param entry_count: {"description": "Total Entries Configured", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param all_hairpinning_drop: {"description": "All Hairpinning Drops", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param icmp_inbound_drop: {"description": "Inbound ICMP Drops", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param fwd_lookup_failed: {"description": "Forward Route Lookup Failed", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param no_match_icmpv6_sent: {"description": "No-Forward-Match ICMPv6 Sent", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param rev_lookup_failed: {"description": "Reverse Route Lookup Failed", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param no_tep_drop: {"description": "LW-4over6 Tunnel Endpoint not Configured Drops", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.interface_not_configured = ""
        self.no_match_icmp_sent = ""
        self.self_hairpinning_drop = ""
        self.entry_count = ""
        self.all_hairpinning_drop = ""
        self.icmp_inbound_drop = ""
        self.fwd_lookup_failed = ""
        self.no_match_icmpv6_sent = ""
        self.rev_lookup_failed = ""
        self.no_tep_drop = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Global(A10BaseClass):
    
    """Class Description::
    Statistics for the object global.

    Class global supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lw-4o6/global/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "global"
        self.a10_url="/axapi/v3/cgnv6/lw-4o6/global/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Distance(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param distance_local: {"description": "Distance for local routes", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param distance_int: {"description": "Distance for routes internal to the AS", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param distance_ext: {"description": "Distance for routes external to the AS", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "distance"
        self.DeviceProxy = ""
        self.distance_local = ""
        self.distance_int = ""
        self.distance_ext = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AggregateAddressList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param as_set: {"default": 0, "type": "number", "description": "Generate AS set path information", "format": "flag"}
    :param summary_only: {"default": 0, "type": "number", "description": "Filter more specific routes from updates", "format": "flag"}
    :param aggregate_address: {"type": "string", "description": "Configure BGP aggregate entries (Aggregate IPv6 prefix)", "format": "ipv6-address-plen"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "aggregate-address-list"
        self.DeviceProxy = ""
        self.as_set = ""
        self.summary_only = ""
        self.aggregate_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Bgp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dampening_max_supress: {"description": "Maximum duration to suppress a stable route(minutes)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param dampening: {"default": 0, "type": "number", "description": "Enable route-flap dampening", "format": "flag"}
    :param dampening_half: {"description": "Reachability Half-life time for the penalty(minutes)", "minimum": 1, "type": "number", "maximum": 45, "format": "number"}
    :param dampening_start_reuse: {"description": "Value to start reusing a route", "minimum": 1, "type": "number", "maximum": 20000, "format": "number"}
    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route-map to specify criteria for dampening (Route-map name)", "format": "string"}
    :param dampening_start_supress: {"description": "Value to start suppressing a route", "minimum": 1, "type": "number", "maximum": 20000, "format": "number"}
    :param dampening_unreachability: {"description": "Un-reachability Half-life time for the penalty(minutes)", "minimum": 1, "type": "number", "maximum": 45, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "bgp"
        self.DeviceProxy = ""
        self.dampening_max_supress = ""
        self.dampening = ""
        self.dampening_half = ""
        self.dampening_start_reuse = ""
        self.route_map = ""
        self.dampening_start_supress = ""
        self.dampening_unreachability = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6(A10BaseClass):
    
    """Class Description::
    ipv6 Address family.

    Class ipv6 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param aggregate_address_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"as-set": {"default": 0, "type": "number", "description": "Generate AS set path information", "format": "flag"}, "summary-only": {"default": 0, "type": "number", "description": "Filter more specific routes from updates", "format": "flag"}, "optional": true, "aggregate-address": {"type": "string", "description": "Configure BGP aggregate entries (Aggregate IPv6 prefix)", "format": "ipv6-address-plen"}}}]}
    :param originate: {"default": 0, "optional": true, "type": "number", "description": "Distribute an IPv6 default route", "format": "flag"}
    :param auto_summary: {"default": 0, "optional": true, "type": "number", "description": "Enable automatic network number summarization", "format": "flag"}
    :param maximum_paths_value: {"description": "Supported BGP multipath numbers", "format": "number", "default": 1, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}
    :param synchronization: {"default": 0, "optional": true, "type": "number", "description": "Perform IGP synchronization", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/bgp/{as_number}/address-family/ipv6`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ipv6"
        self.a10_url="/axapi/v3/router/bgp/{as_number}/address-family/ipv6"
        self.DeviceProxy = ""
        self.distance = {}
        self.redistribute = {}
        self.aggregate_address_list = []
        self.originate = ""
        self.auto_summary = ""
        self.bgp = {}
        self.maximum_paths_value = ""
        self.synchronization = ""
        self.neighbor = {}
        self.network = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class BindingTable(A10BaseClass):
    
    """    :param tunnel_address_list: {"minItems": 1, "items": {"type": "tunnel-address"}, "uniqueItems": true, "array": [{"required": ["ipv6-tunnel-addr"], "properties": {"ipv6-tunnel-addr": {"optional": false, "type": "string", "description": "Tunnel IPv6 Endpoint Address", "format": "ipv6-address"}, "nat-address-list": {"minItems": 1, "items": {"type": "nat-address"}, "uniqueItems": true, "array": [{"required": ["ipv4-nat-addr"], "properties": {"ipv4-nat-addr": {"optional": false, "type": "string", "description": "NAT IPv4 Address", "format": "ipv4-address"}, "port-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "port-start": {"type": "number", "description": "Single Port or Port Range Start", "format": "number"}, "port-end": {"type": "number", "description": "Port Range End", "format": "number"}}}]}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/lw-4o6/binding-table/{name}/tunnel-address/{ipv6-tunnel-addr}/nat-address/{ipv4-nat-addr}"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/lw-4o6/binding-table/{name}/tunnel-address/{ipv6-tunnel-addr}"}
    :param name: {"description": "LW-4over6 Binding Table Name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Configure LW-4over6 Binding Table.

    Class binding-table supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lw-4o6/binding-table/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "binding-table"
        self.a10_url="/axapi/v3/cgnv6/lw-4o6/binding-table/{name}"
        self.DeviceProxy = ""
        self.tunnel_address_list = []
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param alg_pkts_xmitted_num: {"description": "ALG packets rexmitted", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param alg_pasv_helper_freed_unused: {"description": "PASV helper freed unused", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param alg_pasv_helper_created: {"description": "Total PASV helper sessions", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param alg_port_helper_created: {"description": "Total PORT helper sessions", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param sessions_num: {"description": "Total Control Sessions", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param alg_port_helper_nat_free: {"description": "PORT helper NAT free", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param alg_port_helper_freed_unused: {"description": "PORT helper freed unused", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param alg_pkts_num: {"description": "Total ALG packets", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.alg_pkts_xmitted_num = ""
        self.alg_pasv_helper_freed_unused = ""
        self.alg_pasv_helper_created = ""
        self.alg_port_helper_created = ""
        self.sessions_num = ""
        self.alg_port_helper_nat_free = ""
        self.alg_port_helper_freed_unused = ""
        self.alg_pkts_num = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class FtpCtl(A10BaseClass):
    
    """Class Description::
    Statistics for the object ftp-ctl.

    Class ftp-ctl supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/ftp-ctl/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ftp-ctl"
        self.a10_url="/axapi/v3/slb/ftp-ctl/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


